[PATCH 4/5] Export fill_fname() as ckpt_fill_fname()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Acked-by: Serge Hallyn <serue@xxxxxxxxxx>
Signed-off-by: Dan Smith <danms@xxxxxxxxxx>
---
 checkpoint/files.c         |    8 ++++----
 include/linux/checkpoint.h |    2 ++
 2 files changed, 6 insertions(+), 4 deletions(-)

diff --git a/include/linux/checkpoint.h b/include/linux/checkpoint.h
index a6935b3..c3c9436 100644
--- a/include/linux/checkpoint.h
+++ b/include/linux/checkpoint.h
@@ -72,6 +72,8 @@ extern int ckpt_read_string(struct ckpt_ctx *ctx, char **str, int max);
 extern void *ckpt_read_obj_type(struct ckpt_ctx *ctx, int len, int type);
 extern void *ckpt_read_buf_type(struct ckpt_ctx *ctx, int len, int type);
 extern int ckpt_read_consume(struct ckpt_ctx *ctx, int len, int type);
+extern char *ckpt_fill_fname(struct path *path, struct path *root,
+			     char *buf, int *len);
 
 /* ckpt kflags */
 #define ckpt_set_ctx_kflag(__ctx, __kflag)  \
diff --git a/checkpoint/files.c b/checkpoint/files.c
index 78cd9b7..7aecac9 100644
--- a/checkpoint/files.c
+++ b/checkpoint/files.c
@@ -28,14 +28,14 @@
  */
 
 /**
  * fill_fname - return pathname of a given file
  * @path: path name
  * @root: relative root
  * @buf: buffer for pathname
  * @len: buffer length (in) and pathname length (out)
  */
-static char *fill_fname(struct path *path, struct path *root,
-			char *buf, int *len)
+char *ckpt_fill_fname(struct path *path, struct path *root,
+		      char *buf, int *len)
 {
 	struct path tmp = *root;
 	char *fname;
@@ -79,7 +79,7 @@ int checkpoint_fname(struct ckpt_ctx *ctx, struct path *path, struct path *root)
 	if (!buf)
 		return -ENOMEM;
 
-	fname = fill_fname(path, root, buf, &flen);
+	fname = ckpt_fill_fname(path, root, buf, &flen);
 	if (!IS_ERR(fname))
 		ret = ckpt_write_obj_type(ctx, fname, flen,
 					  CKPT_HDR_FILE_NAME);
@@ -28,14 +28,14 @@
 
 /**
- * fill_fname - return pathname of a given file
+ * ckpt_fill_fname - return pathname of a given file
  * @path: path name
  * @root: relative root
-- 
1.6.2.5

_______________________________________________
Containers mailing list
Containers@xxxxxxxxxxxxxxxxxxxxxxxxxx
https://lists.linux-foundation.org/mailman/listinfo/containers

[Index of Archives]     [Cgroups]     [Netdev]     [Linux Wireless]     [Kernel Newbies]     [Security]     [Linux for Hams]     [Netfilter]     [Bugtraq]     [Yosemite Forum]     [MIPS Linux]     [ARM Linux]     [Linux RAID]     [Linux Admin]     [Samba]

  Powered by Linux